module Debate.Arguments.Nutrition.AnabolicKeto exposing (..)

import Debate.Types exposing (..)


argumentAnabolicKeto : Argument
argumentAnabolicKeto =
    { argumentTitle = "Anabolic Opportunity Cost on Keto"
    , propositionTitle = "Ketogenic diets are likely to cost anabolic potential compared to non-ketogenic diets."
    , propositionReductio = ""
    , propositionSummary = "A higher proportion of amino acids are spent on gluconeogenesis while on ketogenic diets, reducing the amount available for hypertrophy. This likely costs anabolic potential on ketogenic diets compared to non-ketogenic diets."
    , proofLink = "https://www.umsu.de/trees/#(P~5Q),(P),(Q~5R)|=(R)"
    , definitionTable =
        [ { definiendum = "P"
          , definiens = "a higher proportion of amino acids are spent on gluconeogenesis while on ketogenic diets compared to non-ketogenic diets"
          }
        , { definiendum = "Q"
          , definiens = "a lower proportion of amino acids are available for hypertrophy on ketogenic diets compared to non-ketogenic diets"
          }
        , { definiendum = "R"
          , definiens = "ketogenic diets are likely to cost anabolic potential compared to non-ketogenic diets"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If a higher proportion of amino acids are spent on gluconeogenesis while on ketogenic diets compared to non-ketogenic diets, then a lower proportion of amino acids are available for hypertrophy on ketogenic diets compared to non-ketogenic diets."
                  , notation = "(P→Q)"
                  }
                , { premise = "A higher proportion of amino acids are spent on gluconeogenesis while on ketogenic diets compared to non-ketogenic diets."
                  , notation = "(P)"
                  }
                , { premise = "If a lower proportion of amino acids are available for hypertrophy on ketogenic diets compared to non-ketogenic diets, then ketogenic diets are likely to cost anabolic potential compared to non-ketogenic diets."
                  , notation = "(Q→R)"
                  }
                ]
          , conclusion = "Therefore, ketogenic diets are likely to cost anabolic potential compared to non-ketogenic diets."
          , conclusionNotation = "(∴R)"
          }
        ]
    }
