module Debate.Arguments.Nutrition.AntagonisticPleiotropy exposing (..)

import Debate.Types exposing (..)


argumentAntagonisticPleiotropy : Argument
argumentAntagonisticPleiotropy =
    { argumentTitle = "Argument Against Ancestral Diets"
    , propositionTitle = "Ancestral diets have inherent disadvantages over novel diets"
    , propositionReductio = ""
    , propositionSummary = "Humans have more genetic adaptations to ancestral foods than novel foods, which makes the long-term negative consequences of antagonistic pleiotropy a greater concern for ancestral foods."
    , proofLink = "https://www.umsu.de/trees/#(P~5Q),(Q~5R),(P)|=(R)"
    , definitionTable =
        [ { definiendum = "P"
          , definiens = "humans have more genetic adaptations to ancestral foods than novel foods"
          }
        , { definiendum = "Q"
          , definiens = "antagonistic pleiotropy is more of a concern for ancestral foods than novel foods"
          }
        , { definiendum = "R"
          , definiens = "ancestral foods have inherent disadvantages over novel foods"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If humans have more genetic adaptations to ancestral foods than novel foods, then antagonistic pleiotropy is more of a concern for ancestral foods than novel foods."
                  , notation = "(P→Q)"
                  }
                , { premise = "If antagonistic pleiotropy is more of a concern for ancestral foods than novel foods, then ancestral diets have inherent disadvantages over novel diets."
                  , notation = "(Q→R)"
                  }
                , { premise = "Humans have more genetic adaptations to ancestral foods than novel foods."
                  , notation = "(P)"
                  }
                ]
          , conclusion = "Therefore, ancestral foods have inherent disadvantages over novel foods"
          , conclusionNotation = "(∴R)"
          }
        ]
    }
