module Debate.Arguments.Nutrition.HealthyChocolate exposing (..)

import Debate.Types exposing (..)


argumentHealthyChocolate : Argument
argumentHealthyChocolate =
    { argumentTitle = "Argument Against Atherogenic Chocolate"
    , propositionTitle = "Chocolate does not cause atherosclerosis."
    , propositionReductio = ""
    , propositionSummary = "Despite chocolate containing high amounts of saturated fat, populations that consume more chocolate do not exhibit higher rates of atherosclerosis, suggesting that chocolate does not have the same effect on heart disease risk as most other saturated fat sources."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~5Qx)),(~3Qc)|=(~3Pc)"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) causes atherosclerosis"
          }
        , { definiendum = "Q(x)"
          , definiens = "populations consuming more (x) have higher rates of atherosclerosis after adjustment or control over relevant confounders and covariates."
          }
        , { definiendum = "x"
          , definiens = "a high saturated fat food"
          }
        , { definiendum = "c"
          , definiens = "chocolate"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a high saturated fat food causes atherosclerosis, then populations consuming more of this high saturated fat food have higher rates of atherosclerosis after adjustment or control over relevant confounders and covariates."
                  , notation = "(∀x(Px→Qx))"
                  }
                , { premise = "Populations consuming more chocolate do not have higher rates of atherosclerosis after adjustment or control over relevant confounders and covariates."
                  , notation = "(¬Qc)"
                  }
                ]
          , conclusion = "Therefore, chocolate does not cause atherosclerosis."
          , conclusionNotation = "(∴¬Pc)"
          }
        ]
    }
