module Debate.Arguments.Nutrition.HealthyDairy exposing (..)

import Debate.Types exposing (..)

argumentHealthyDairy : Argument
argumentHealthyDairy =
    { argumentTitle = "Argument for Healthy Dairy Products"
    , propositionTitle = "Non-churned, non-homogenized dairy do not cause atherosclerosis."
    , propositionReductio = ""
    , propositionSummary = "The diet-heart hypothesis would predict that populations consuming more dairy foods should have higher rates of the disease. However, even when you account for factors that could plausibly influence the results, non-churned, non-homogenized dairy have been shown to consistently reduce the risk of morbidity and mortality, strongly suggesting that they directly contribute to better health outcomes, particularly with respect to cardiovascular disease and colorectal cancer."
    , proofLink  = "https://www.umsu.de/trees/#(~6x(Px~5Qx)),(~3Qh)|=(~3Ph)"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) causes atherosclerosis"
          }
        , { definiendum = "Q(x)"
          , definiens = "populations consuming more (x) have higher rates of atherosclerosis after adjustment or control over relevant confounders and covariates"
          }
        , { definiendum = "x"
          , definiens = "high saturated fat food"
          }
        , { definiendum = "h"
          , definiens = "non-churned, non-homogenized dairy"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a high saturated fat food causes atherosclerosis, then populations consuming more of the high saturated fat food have higher rates of atherosclerosis after adjustment or control over relevant confounders and covariates."
                  , notation = "(∀x(Px→Qx))"
                  }
                , { premise = "Populations consuming more non-churned, non-homogenized dairy do not have higher rates of atherosclerosis after adjustment or control over relevant confounders and covariates."
                  , notation = "(¬Qh)"
                  }
                ]
          , conclusion = "Therefore, non-churned, non-homogenized dairy do not cause atherosclerosis."
          , conclusionNotation = "(∴¬Ph)"
          }
        ]
    }