module Debate.Arguments.Nutrition.HealthyFattyFish exposing (..)

import Debate.Types exposing (..)


argumentHealthyFattyFish : Argument
argumentHealthyFattyFish =
    { argumentTitle = "Argument for Overwhelmingly Healthy Fatty Fish"
    , propositionTitle = "Fatty fish is overwhelmingly healthy."
    , propositionReductio = ""
    , propositionSummary = "Even when you account for factors that could plausibly influence the results, fatty fish have been shown to consistently reduce the risk of morbidity and mortality, strongly suggesting that they directly contribute to better health outcomes, particularly with respect to cardiovascular disease."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(Qf)|=(Pf)"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) is overwhelmingly healthy"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) consistently associates with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates"
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "f"
          , definiens = "fatty fish"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, a food is overwhelmingly healthy if, and only if, the food consistently associates with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates."
                  , notation = "(∀x(Px↔Qx))"
                  }
                , { premise = "Fatty fish consistently associates with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates."
                  , notation = "(Qf)"
                  }
                ]
          , conclusion = "Therefore, fatty fish is overwhelmingly healthy."
          , conclusionNotation = "(∴Pf)"
          }
        ]
    }
