module Debate.Arguments.Nutrition.HealthyFibre exposing (..)

import Debate.Types exposing (..)


argumentHealthyFibre : Argument
argumentHealthyFibre =
    { argumentTitle = "Argument for Overwhelmingly Healthy Fibre"
    , propositionTitle = "Fibre, whether whole or refined, is overwhelmingly healthy."
    , propositionReductio = ""
    , propositionSummary = "Even when you account for factors that could plausibly influence the results, both refined and whole fibre have been shown to consistently reduce the risk of morbidity and mortality, strongly suggesting that they directly contribute to better health outcomes, particularly with respect to cardiovascular disease."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(Qb)|=(Pb)"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) is overwhelmingly healthy"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) consistently associates with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates"
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "b"
          , definiens = "fibre"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, a food is overwhelmingly healthy if, and only if, the food consistently associates with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates."
                  , notation = "(∀x(Px↔Qx))"
                  }
                , { premise = "Fibre, whether whole or refined, consistently associates with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates."
                  , notation = "(Qb)"
                  }
                ]
          , conclusion = "Therefore, fibre, whether whole or refined, is overwhelmingly healthy."
          , conclusionNotation = "(∴Pb)"
          }
        ]
    }
