module Debate.Arguments.Nutrition.HealthyFood exposing (..)

import Debate.Types exposing (..)


argumentHealthyFood : Argument
argumentHealthyFood =
    { argumentTitle = "Argument For Healthy Food Substitution"
    , propositionTitle = "Pepsi is healthy compared to leafy greens when trapped on a desert island."
    , propositionReductio = ""
    , propositionSummary = "A food is considered healthier than another in a specific context if it increases the time before illness or disease sets in when replacing the other food. On a desert island, since Pepsi can extend the time before starvation compared to leafy greens, it is considered healthier than leafy greens in that context."
    , proofLink = "https://www.umsu.de/trees/#(~6x~6y~6z~6w(Pxyw~4Qwxzy)),(Qdpsl)|=(Ppld)"
    , definitionTable =
        [ { definiendum = "P(x,y,w)"
          , definiens = "(x) is healthy compared to (w) when in (y)"
          }
        , { definiendum = "Q(x,y,z,w)"
          , definiens = "when within a (y), the consumption of (x) is likely to increase the lag-time to the onset of (z) when replacing (w)"
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "y"
          , definiens = "a another food"
          }
        , { definiendum = "z"
          , definiens = "an illness or disease"
          }
        , { definiendum = "w"
          , definiens = "a context"
          }
        , { definiendum = "p"
          , definiens = "Pepsi"
          }
        , { definiendum = "d"
          , definiens = "trapped on a desert island"
          }
        , { definiendum = "s"
          , definiens = "starvation"
          }
        , { definiendum = "l"
          , definiens = "leafy greens"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "A given a food is healthy compared to another given food when in a given context if, and only if, when within that context, the consumption of that given a food is likely to increase the lag-time to the onset of illness, disease, or infirmity when replacing a given other food."
                  , notation = "(∀x∀y∀z∀w(Pxyw↔Qwxzy))"
                  }
                , { premise = "When trapped on a desert island the consumption of Pepsi increases the lag-time to the onset of starvation when replacing leafy greens."
                  , notation = "(Qdpsl)"
                  }
                ]
          , conclusion = "Therefore, Pepsi is healthy compared to leafy greens when trapped on a desert island."
          , conclusionNotation = "(∴Ppld)"
          }
        ]
    }
