module Debate.Arguments.Nutrition.HealthySeedOils exposing (..)

import Debate.Types exposing (..)


argumentHealthySeedOils : Argument
argumentHealthySeedOils =
    { argumentTitle = "Argument for Overwhelmingly Healthy Seed Oils"
    , propositionTitle = "Non-hydrogenated vegetable oils are overwhelmingly healthy."
    , propositionReductio = ""
    , propositionSummary = "Even when you account for factors that could plausibly influence the results, non-hydrogenated vegetable oils have been shown to consistently reduce the risk of morbidity and mortality, strongly suggesting that they directly contribute to better health outcomes."
    , proofLink  = "https://www.umsu.de/trees/#(~6x(Px~5Qx)),(Pv)|=(Qv)"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) is overwhelmingly healthy"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) consistently associates with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates"
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "v"
          , definiens = "non-hydrogenated vegetable oils"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, a food is overwhelmingly healthy if, and only if, the food consistently associates with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates."
                  , notation = "(∀x(Px↔Qx))"
                  }
                , { premise = "Non-hydrogenated vegetable oils consistently associate with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates."
                  , notation = "(Pv)"
                  }
                ]
          , conclusion = "Therefore, non-hydrogenated vegetable oils are overwhelmingly healthy."
          , conclusionNotation = "(∴Qv)"
          }
        ]
    }