module Debate.Arguments.Nutrition.HealthySoy exposing (..)

import Debate.Types exposing (..)


argumentHealthySoy : Argument
argumentHealthySoy =
    { argumentTitle = "Argument for Soy Products"
    , propositionTitle = "Soy products are overwhelmingly healthy."
    , propositionReductio = ""
    , propositionSummary = "Even when you account for factors that could plausibly influence the results, non-hydrogenated soy products have been shown to consistently reduce the risk of morbidity and mortality, strongly suggesting that they directly contribute to better health outcomes, particularly with respect to cardiovascular disease."
    , proofLink  = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(Qs)|=(Ps)"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) is overwhelmingly healthy"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) consistently associates with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates"
          }
        , { definiendum = "x"
          , definiens = "a food"
          }
        , { definiendum = "s"
          , definiens = "soy products"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, a food is overwhelmingly healthy if, and only if, the food consistently associates with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates."
                  , notation = "(∀x(Px↔Qx))"
                  }
                , { premise = "Soy products consistently associate with a reduced risk of morbidity and mortality after adjustment or control over relevant confounders and covariates."
                  , notation = "(Qs)"
                  }
                ]
          , conclusion = "Therefore, soy products are overwhelmingly healthy."
          , conclusionNotation = "(∴Ps)"
          }
        ]
    }