module Debate.Arguments.Nutrition.Malondialdehyde exposing (..)

import Debate.Types exposing (..)


argumentMalondialdehyde : Argument
argumentMalondialdehyde =
    { argumentTitle = "Atherogenic Omega-3 Reductio"
    , propositionTitle = "Omega-3s are atherogenic."
    , propositionReductio = ""
    , propositionSummary = "If one takes the view that in order for a substance to increase the risk of atherosclerosis, it must facilitate the oxidative modification of LDL particles via malondialdehyde production, and one also affirms that omega-3s are anti-atherogenic, then this would imply that all fatty acids that produce malondialdehyde, including omega-3s, must also be atherogenic, which contradicts the their belief that omega-3s are heart-healthy."
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4Qx)),(Qm),(Pm~5~6x(Rx))%7C=(Ro)"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) increases the risk of atherosclerosis"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) facilitates the oxidative modification of LDL particles"
          }
        , { definiendum = "R(x)"
          , definiens = "all (x) are atherogenic"
          }
             , { definiendum = "x"
          , definiens = "a substance"
          }
                 , { definiendum = "y"
          , definiens = "malondialdehyde-producing fatty acids"
          }
        , { definiendum = "m"
          , definiens = "malondialdehyde"
          }
        , { definiendum = "o"
          , definiens = "omega-3s"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "A substance increases the risk of atherosclerosis if, and only if, that substance facilitates the oxidative modification of LDL particles."
                  , notation = "(∀x(Px↔Qx))"
                  }
                , { premise = "Malondialdehyde facilitates the oxidative modification of LDL particles."
                  , notation = "(Qm)"
                  }
                , { premise = "If malondialdehyde increases the risk of atherosclerosis, then all malondialdehyde-producing fatty acids are atherogenic."
                  , notation = "(Pm→∀y(Ry))"
                  }
                ]
          , conclusion = "Therefore, omega-3s are atherogenic."
          , conclusionNotation = "(∴Ro)"
          }
        ]
    }
