module Debate.Arguments.Nutrition.PolyphenolReductio exposing (..)

import Debate.Types exposing (..)


argumentPolyphenolReductio : Argument
argumentPolyphenolReductio =
    { argumentTitle = "Anti-Polyphenol Reductio"
    , propositionTitle = "Anti-polyphenol, ancestral diet advocates are committed to favouring GMOs."
    , propositionReductio = "asdasd"
    , propositionSummary = "Summary"
    , proofLink = "https://www.umsu.de/trees/#(~6x~6y(Px~1Qxy~5Rxy)),(Pp),(Qpg),(Rpg~5Spg),(Spg~5Wp)|=(Wp)"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) is harmful"
          }
        , { definiendum = "Q(x,y)"
          , definiens = "(x) is contained in (y)"
          }
        , { definiendum = "R(x,y)"
          , definiens = "(x) renders (y) harmful"
          }
        , { definiendum = "S(p,g)"
          , definiens = "genetic modification that removes (p) from grass renders (g) less harmful"
          }
        , { definiendum = "W(p)"
          , definiens = "health-conscious, anti-polyphenol, ancestral diet advocates are committed to favouring GMOs"
          }
        , { definiendum = "x"
          , definiens = "plant defense chemicals"
          }
        , { definiendum = "y"
          , definiens = "a food"
          }
        , { definiendum = "p"
          , definiens = "polyphenols"
          }
        , { definiendum = "g"
          , definiens = "grass-fed beef"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If plant defense chemicals are harmful and plant defense chemicals are contained in a food, then plant defense chemicals render the food harmful."
                  , notation = "(∀x∀y(Px∧Qxy→Rxy))"
                  }
                , { premise = "Polyphenols from grass are harmful."
                  , notation = "(Pp)"
                  }
                , { premise = "Polyphenols from grass are contained in grass-fed beef."
                  , notation = "(Qpg)"
                  }
                , { premise = "If polyphenols from grass render grass-fed beef harmful, then genetic modification that removes polyphenols from grass renders grass-fed beef less harmful."
                  , notation = "(Rpg→Spg)"
                  }
                , { premise = "If genetic modification that removes polyphenols from grass renders grass-fed beef less harmful, then health-conscious, anti-polyphenol, ancestral diet advocates are committed to favouring GMOs."
                  , notation = "(Spg→Wp)"
                  }
                ]
          , conclusion = "Therefore, health-conscious, anti-polyphenol, ancestral diet advocates are committed to favouring GMOs."
          , conclusionNotation = "(∴Wp)"
          }
        ]
    }
