module Debate.Arguments.Nutrition.SodiumCVD exposing (..)

import Debate.Types exposing (..)

argumentSodiumCVD : Argument
argumentSodiumCVD =
    { argumentTitle = "Argument for Atherogenic Sodium"
    , propositionTitle = "Higher intakes of sodium increases cardiovascular disease risk."
    , propositionReductio = ""
    , propositionSummary = "Summary"
    , proofLink  = "https://www.umsu.de/trees/#(~6x(Px~1Q~5Rx)),(Ps),(Q)|=(Rs)"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) consistently raises blood pressure in controlled studies"
          }
        , { definiendum = "Q(x)"
          , definiens = "elevated blood pressure is known to cause cardiovascular disease"
          }
        , { definiendum = "R(x)"
          , definiens = "higher intakes of substance (x) increases cardiovascular disease risk"
          }
              , { definiendum = "x"
          , definiens = "a substance"
          }
        , { definiendum = "s"
          , definiens = "sodium"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "For all things, if a substance consistently raises blood pressure in controlled studies and elevated blood pressure is known to cause cardiovascular disease, then higher intakes of that substance increases cardiovascular disease risk."
                  , notation = "(∀x(Px∧Q→Rx))"
                  }
                , { premise = "Sodium consistently raises blood pressure in controlled studies."
                  , notation = "(Ps)"
                  }
                , { premise = "Elevated blood pressure is known to cause cardiovascular disease."
                  , notation = "(Q)"
                  }
                ]
          , conclusion = "Therefore, higher intakes of sodium increases cardiovascular disease risk."
          , conclusionNotation = "(∴Rs)"
          }
        ]
    }
