module Debate.Arguments.Philosophy.Abortion exposing (..)

import Debate.Types exposing (..)


argumentAbortion : Argument
argumentAbortion =
    { argumentTitle = "Abortion Rights"
    , propositionTitle = "One's whims are not a sufficient justification for the termination of sentient human life."
    , propositionReductio = ""
    , propositionSummary = "Summary"
    , proofLink = "https://www.umsu.de/trees/#(P~2Q~5R),(P),(Q),((R~1F~1~3H)~5M),(F),(~3H),(M~5~3W)%7C=(~3W)"
    , definitionTable =
        [ { definiendum = "P"
          , definiens = "one consents to becoming pregnant"
          }
        , { definiendum = "Q"
          , definiens = "one consensually engages in sexual activity without contraception"
          }
        , { definiendum = "R"
          , definiens = "one is implicitly committed to at least accepting the average risks for the average pregnancy"
          }
        , { definiendum = "F"
          , definiens = "one's pregnancy persists long enough for fetal sentience to develop"
          }
        , { definiendum = "H"
          , definiens = "one's risk profile during pregnancy is high"
          }
        , { definiendum = "M"
          , definiens = "one is morally bound to carrying the pregnancy to term"
          }
        , { definiendum = "W"
          , definiens = "one's whims are a sufficient justification for the termination of sentient human life"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If one consents to becoming pregnant or one consensually engages in sexual activity without contraception, then one is implicitly committed to at least accepting the average risks for the average pregnancy."
                  , notation = "(P∨Q→R)"
                  }
                , { premise = "One consents to becoming pregnant."
                  , notation = "(P)"
                  }
                , { premise = "One consensually engages in sexual activity without contraception."
                  , notation = "(Q)"
                  }
                , { premise = "If one is implicitly committed to at least accepting the average risks for the average pregnancy and one's pregnancy persists long enough for fetal sentience to develop and one's risk profile during pregnancy is not high, then one is morally bound to carrying the pregnancy to term."
                  , notation = "(R∧F∧¬H→M)"
                  }
                , { premise = "One's pregnancy persists long enough for fetal sentience to develop."
                  , notation = "(F)"
                  }
                , { premise = "One's risk profile during pregnancy is not high."
                  , notation = "(¬H)"
                  }
                , { premise = "If one is morally bound to carrying the pregnancy to term, then one's whims are not a sufficient justification for the termination of sentient human life."
                  , notation = "(M→¬W)"
                  }
                ]
          , conclusion = "Therefore, one's whims are not a sufficient justification for the termination of sentient human life."
          , conclusionNotation = "(∴¬W)"
          }
        ]
    }
