module Debate.Arguments.Philosophy.Agnosticism exposing (..)

import Debate.Types exposing (..)


argumentAgnosticism : Argument
argumentAgnosticism =
    { argumentTitle = "Agnosticism Consistency Checker"
    , propositionTitle = "An interlocutor (who cannot unpack what evidence would lead them to change their doxastic attitude on a proposition) should temporarily withhold the belief that the proposition at hand is true."
    , propositionReductio = ""
    , propositionSummary = "Summary"
    , proofLink = "https://www.umsu.de/trees/#(~6x~6y(~3Pxy~5~3Qxy)),(~6x~6y(~3Qxy~5Rxy)),(~3Por)|=(Ror)"
    , definitionTable =
        [ { definiendum = "P(x,y)"
          , definiens = "(x) can unpack what evidence would lead them to change their doxastic attitude on (y)"
          }
        , { definiendum = "Q(x,y)"
          , definiens = "(x) knows why they believe that (y) is true"
          }
        , { definiendum = "R(x,y)"
          , definiens = "(x) should temporarily withhold the belief that (y) is true"
          }
        , { definiendum = "x"
          , definiens = "a person"
          }
        , { definiendum = "y"
          , definiens = "a proposition"
          }
        , { definiendum = "o"
          , definiens = "the interlocutor"
          }
        , { definiendum = "r"
          , definiens = "the proposition at hand"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If one cannot unpack what evidence would lead them to change their doxastic attitude on a proposition, then one does does not know why they believe that a proposition is true."
                  , notation = "(∀x∀y(¬Pxy→¬Qxy))"
                  }
                , { premise = "If one does not know why they believe that a proposition is true, then one should temporarily withhold the belief that a proposition is true."
                  , notation = "(∀x∀y(¬Qxy→Rxy))"
                  }
                , { premise = "The interlocutor cannot unpack what evidence would lead them to change their doxastic attitude on the proposition at hand."
                  , notation = "(¬Por)"
                  }
                ]
          , conclusion = "Therefore, the interlocutor should temporarily withhold the belief that the proposition at hand is true."
          , conclusionNotation = "(∴Ror)"
          }
        ]
    }
