module Debate.Arguments.Philosophy.Ostroveganism exposing (..)

import Debate.Types exposing (..)


argumentOstroveganism : Argument
argumentOstroveganism =
    { argumentTitle = "Argument for Vegan Bivalves"
    , propositionTitle = "Bivalves are not likely to be sentient."
    , propositionReductio = ""
    , propositionSummary = "Summary"
    , proofLink = "https://www.umsu.de/trees/#(~6x(Px~4Qx~1Rx~1(Sx~2Wx))),(Qc~1~3Rc~1Sc~1~3Wc),(~3Pc~5~6x(~3Tx))|=(~3Tb)"
    , definitionTable =
        [ { definiendum = "P(x)"
          , definiens = "(x) counts as a brain"
          }
        , { definiendum = "Q(x)"
          , definiens = "(x) is a complex network of interconnected neurons"
          }
        , { definiendum = "R(x)"
          , definiens = "(x) integrates neuronal pathways from multiple sensory organs"
          }
        , { definiendum = "S(x)"
          , definiens = "(x) presents with distinct functional regions"
          }
        , { definiendum = "W(x)"
          , definiens = "(x) presents with nuclei with white matter tracts that facilitate inter-regional communication"
          }
        , { definiendum = "T(x)"
          , definiens = "the corresponding (y) is likely to be sentient"
          }
        , { definiendum = "x"
          , definiens = "an object"
          }
        , { definiendum = "y"
          , definiens = "brainless biological system into which cerebral ganglia are integrated"
          }
        , { definiendum = "c"
          , definiens = "cerebral ganglia"
          }
        , { definiendum = "b"
          , definiens = "bivalves"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "Something counts as a brain if, and only if, something is a complex network of interconnected neurons, integrates neuronal pathways from multiple sensory organs, and presents with distinct functional regions or nuclei with white matter tracts that facilitate inter-regional communication."
                  , notation = "(∀x(Px↔Qx∧Rx∧(Sx∨Wx)))"
                  }
                , { premise = "Cerebral ganglia meet criteria one and three, but not criteria two and four."
                  , notation = "(Qc∧¬Rc∧Sc∧¬Wc)"
                  }
                , { premise = "If cerebral ganglia do not count as brains, then the corresponding brainless biological system into which the cerebral ganglia are integrated is not likely to be sentient."
                  , notation = "(¬Pc→∀x(¬Tx))"
                  }
                ]
          , conclusion = "Therefore, bivalves are not likely to be sentient."
          , conclusionNotation = "(∴¬Tb)"
          }
        ]
    }
