module Debate.Arguments.Science.FlatEarthDebunk exposing (..)

import Debate.Types exposing (..)


argumentFlatEarthDebunk : Argument
argumentFlatEarthDebunk =
    { argumentTitle = "Flat Earth Internal Critique"
    , propositionTitle = "The stars in the sky will not be perceived as rotating clockwise from anywhere else on the flat Earth, as long as you are looking towards the rotational plane."
    , propositionReductio = ""
    , propositionSummary = "The argument is structured to demonstrate that, within the context of a flat Earth model, if the stars are perceived as rotating counter-clockwise from the center, they cannot also be perceived as rotating clockwise from any point on the Earth."
    , proofLink = "https://www.umsu.de/trees/#(~6x~6y~6z(Pxy~5(Qyz~5Rxz))),(Pkt~1Qta),(Rka~5~3Ska)|=(~3Ska)"
    , definitionTable =
        [ { definiendum = "P(x,y)"
          , definiens = "(x) is perceived as rotating counter-clockwise from point (y)"
          }
        , { definiendum = "Q(y,z)"
          , definiens = "(y) is on the same side of the rotational plane as (z)"
          }
        , { definiendum = "R(x,z)"
          , definiens = "(x) will be perceived as rotating counter-clockwise from (z), as long as you are looking towards the plane"
          }
        , { definiendum = "S(x,z)"
          , definiens = "(x) will be perceived as rotating clockwise from (z), as long as you are looking towards the plane"
          }
        , { definiendum = "x"
          , definiens = "an object"
          }
        , { definiendum = "y"
          , definiens = "vantage point A"
          }
        , { definiendum = "z"
          , definiens = "vantage points B"
          }
        , { definiendum = "k"
          , definiens = "stars in the sky"
          }
        , { definiendum = "t"
          , definiens = "the center of the flat Earth"
          }
        , { definiendum = "a"
          , definiens = "anywhere else on the flat Earth"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If an object is perceived as rotating counter-clockwise from vantage point A, then, for all vantage points B, if vantage point A is on the same side of the rotational plane as vantage points B, then the object will be perceived as rotating counter-clockwise from vantage points B, as long as you are looking towards the rotational plane."
                  , notation = "(∀x∀y∀z(Pxy→(Qyz→Rxz)))"
                  }
                , { premise = "The stars in the sky are perceived as rotating counter-clockwise from the center of the flat Earth and the center of the flat Earth is on the same side of the rotational plane as anywhere else on the flat Earth."
                  , notation = "(Pkt∧Qta)"
                  }
                , { premise = "If the stars in the sky are perceived as rotating counter-clockwise from anywhere else on the flat Earth, as long as you are looking towards the rotational plane, then the stars in the sky will not be perceived as rotating clockwise from anywhere else on the flat Earth, as long as you are looking towards the rotational plane."
                  , notation = "(Rka→¬Ska)"
                  }
                ]
          , conclusion = "Therefore, the stars in the sky will not be perceived as rotating clockwise from anywhere else on the flat Earth, as long as you are looking towards the rotational plane."
          , conclusionNotation = "(∴¬Ska)"
          }
        ]
    }
